@@ -2,7 +2,7 @@
 
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -53,15 +53,24 @@ class Repository(AnyEntity):
 
     # navigation in versioned content #########################################
 
+    def latest_known_revision(self):
+        """return the number of the latest known revision"""
+        latestrev = self.req.execute(
+            'Any MAX(REVR) WHERE R eid %(r)s, REV from_repository R, '
+            'REV revision REVR', {'r' : self.eid}, 'r')[0][0]
+        if latestrev is None:
+            return -1
+        return latestrev
+
     def branches(self):
+        """return existing branches"""
         return [b for b, in self.req.execute(
-            'DISTINCT Any B WHERE R eid %(r)s, REV from_repository REPO, '
+            'DISTINCT Any B WHERE R eid %(r)s, REV from_repository R, '
             'REV branch B', {'r' : self.eid}, 'r')]
 
     @cached
     def branch_head(self, branch=_MARKER):
-        """return latest revision of the given branch
-        """
+        """return latest revision of the given branch"""
         if branch is _MARKER:
             branch = self.default_branch()
         rset = self.req.execute(
@@ -77,8 +86,7 @@ class Repository(AnyEntity):
             'Any X WHERE X is VersionedFile, X from_repository R, '
             'R eid %(repo)s, X directory %(dir)s, X name %(name)s',
             {'repo' : self.eid, 'dir' : directory, 'name' : filename})
-        assert len(rset) == 1, rset
-        return rset.get_entity(0, 0)
+        return rset and rset.get_entity(0, 0) or None
 
     def is_directory_deleted(self, directory):
         # XXX same MAX(X) trick as above
@@ -115,12 +123,31 @@ class Repository(AnyEntity):
         rset = self.req.execute(queries.new_revision_rql(parent), args)
         return rset.get_entity(0, 0)
 
-    def vcs_add(self, filedir, filename, stream, **kwargs):
-        vf = self.req.execute(queries.new_file_rql(),
-                              {'repoeid': self.eid, 'directory': filedir,
-                               'name': filename}).get_entity(0, 0)
+    def vcs_add(self, filedir, filename, stream, strict=False,
+                extraattrs=None, **kwargs):
+        """add the file into the repository, as <filedir>/<filename>, with
+        content specified in <stream> (Binary instance).
+
+        If strict and the file already exists in the repository, an error will
+        be raised, else a new revision will be simply uploaded.
+
+        If you've an extended versioned file's schema you can give additional
+        attributes to create_entity using the extraattrs argument (expected to
+        be a dict)
+
+        Return the VersionedFile instance.
+        """
+        vf = self.versioned_file(filedir, filename)
+        if not vf:
+            if extraattrs is None:
+                extraattrs = {}
+            vf = self.req.create_entity('VersionedFile',
+                                        from_repository=self, directory=filedir,
+                                        name=filename, **extraattrs)
+        elif strict:
+            raise Exception('attempting to add an already existing file')
         vf.vcs_upload_revision(stream, **kwargs)
-        return vf.eid
+        return vf
 
 
 class Revision(AnyEntity):
@@ -190,7 +217,7 @@ class VersionedFile(AnyEntity):
 
     # XXX branches
     def dc_title(self):
-        if self.revision_deleted():
+        if self.deleted_in_branch():
             return '%s (%s)' % (self.path, self.req._('DELETED'))
         return self.path
 
@@ -235,7 +262,7 @@ class VersionedFile(AnyEntity):
         rset = self.req.execute(
             'Any C,VF,R WHERE C content_for VF, C from_revision R, '
             'R revision %(rnum)s, VF eid %(x)s',
-            {'rnum' : revnum, 'x' : self.eid}, 'x')
+            {'rnum' : int(revnum), 'x' : self.eid}, 'x')
         if rset:
             return rset.get_entity(0, 0)
         return None
@@ -260,23 +287,7 @@ class VersionedFile(AnyEntity):
         """deleted in branch != does not even exist in branch
         """
         head = self.branch_head(branch)
-        return head and not isinstance(self.branch_head(branch), VersionContent) or False
-
-    def revision_deleted(self, revnum=None):
-        return not isinstance(self.version_content(revnum), VersionContent)
-
-    def revnum_author_msg_branch(self):
-        """return an ordered list of
-
-           (vcs revision number, author, commit message, branch)
-
-        where this document has been modified
-        """
-        return self.req.execute(
-            'DISTINCT Any RNUM, A, D, B ORDERBY RNUM, A, D, B '
-            'WHERE C from_revision REV, REV revision RNUM, REV author A, '
-            'REV branch B, REV description D, C content_for VF, VF eid %(x)s',
-            {'x' : self.eid}, 'x')
+        return head and head.is_deletion() or False
 
     # vcs write support #######################################################
 
@@ -303,12 +314,14 @@ class VersionedFile(AnyEntity):
         """upload a new revision for this file to the vcs
 
         either takes a rev or a kwargs having keys: branch, msg, author
+
+        return the newly created version content entity
         """
         if rev is None:
             rev = self.repository.make_revision(**kwargs)
         return self.req.execute(queries.new_file_content_rql(),
                                 {'vfeid' : self.eid, 'reveid' : rev.eid,
-                                 'data' : Binary(stream.read())})[0][0]
+                                 'data' : Binary(stream.read())}).get_entity(0, 0)
 
 
 class DeletedVersionContent(AnyEntity):
@@ -372,10 +385,7 @@ class DeletedVersionContent(AnyEntity):
 
     @property
     def head(self):
-        return self.file.head
-
-    def is_head(self, branch=_MARKER):
-        return self.eid == self.file.branch_head(branch).eid
+        return self.file.branch_head(self.rev.branch)
 
     # < 0.7 bw compat properties
     @property
@@ -390,6 +400,17 @@ class DeletedVersionContent(AnyEntity):
     def description(self):
         return self.from_revision[0].description
 
+    def is_head(self, branch=_MARKER):
+        """return true if this version content is the head for its file in
+        the given branch or in its revision's branch.
+        """
+        if branch is _MARKER:
+            branch = self.rev.branch
+        return self.eid == self.file.branch_head(branch).eid
+
+    def is_deletion(self):
+        return True
+
 
 class VersionContent(DeletedVersionContent):
     """customized class for VersionContent entities"""
@@ -419,6 +440,9 @@ class VersionContent(DeletedVersionContent):
             self.__data = data
             return data
 
+    def is_deletion(self):
+        return False
+
     # IDownloadable
     def download_url(self):
         return self.absolute_url(vid='download')
