@@ -2,7 +2,7 @@
 """hooks for vcsfile content types
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -42,7 +42,8 @@ class ServerStartupHook(Hook):
         repo.system_source.map_attribute('VersionContent', 'data',
                                          _generate_vc_data)
         repo.looping_task(repo.config.get('check-revision-interval', 5*60),
-                          bridge.import_content, repo)
+                          bridge.import_content, repo,
+                          repo.config.get('check-revision-commit-every', 5*60))
 
 
 class AddRepositoryHook(Hook):
@@ -142,7 +143,8 @@ class AddRevisionHook(Hook):
         # should not have multiple transaction on the same repository
         if vcsrepoeid in transactions:
             raise QueryError('already processing a new revision')
-        vcsrepohdlr = bridge.repository_handler(vcsrepoeid)
+        vcsrepohdlr = bridge.cache_handler_for_repository(
+            session.entity_from_eid(vcsrepoeid))
         transaction = vcsrepohdlr.revision_transaction(session, entity)
         transaction.reveid = entity.eid
         transactions[vcsrepoeid] = transaction
