@@ -1,7 +1,7 @@
 """repository abstraction for a mercurial repository
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -41,9 +41,11 @@ class HGRepository(repo.VCSRepository):
         except Exception, ex:
             self.error('Impossible to open repository %s (%s)', self, ex)
             return
-        actualrev = bw_nb_revisions(repo.changelog)
+        # actual rev is the *number* of revision, latest rev the highest
+        # revision number while hg revisions start at 0 -> - 1
+        actualrev = bw_nb_revisions(repo.changelog) - 1
         session = repoentity.req
-        latestrev = repoentity.latest_known_revision
+        latestrev = repoentity.latest_known_revision()
         if actualrev < latestrev:
             # striped repo
             # very minimal support, this won't work if local number of
@@ -52,11 +54,10 @@ class HGRepository(repo.VCSRepository):
                          'repository revision is %s', latestrev, actualrev)
             session.execute('DELETE Revision X WHERE X revision >= %(rev)s',
                             {'rev': actualrev})
-            repoentity.set_attributes(latest_known_revision=actualrev)
             return
         self.info('hg repo %s: known revisions up to %s, repo revision %s',
                   repoentity.path, latestrev, actualrev)
-        for i in xrange(latestrev, actualrev):
+        for i in xrange(latestrev + 1, actualrev + 1):
             self.info('importing revision %s', i)
             try:
                 self.import_revision(repoentity, repo, i)
@@ -65,13 +66,10 @@ class HGRepository(repo.VCSRepository):
                               i, repoentity.path)
                 raise
             if not i % commitevery:
-                repoentity.set_attributes(latest_known_revision=i)
                 # give a change to threads waiting for a pool by freeing it then
                 # reacquiring it
                 session.commit()
                 session.set_pool()
-        if actualrev > latestrev:
-            repoentity.set_attributes(latest_known_revision=actualrev)
 
     def import_revision(self, repoentity, repo, i):
         session = repoentity.req
