@@ -45,7 +45,7 @@ class SVNRepository(repo.VCSRepository):
             return
         callbacks = ra.Callbacks()
         #ra_ctx = ra.open2('file://' + self.path, callbacks, None, None)
-        latestrev = rev = repoentity.latest_known_revision
+        latestrev = rev = repoentity.latest_known_revision()
         actualrev = fs.youngest_rev(fsrep)
         session = repoentity.req
         while rev < actualrev:
@@ -67,13 +67,10 @@ class SVNRepository(repo.VCSRepository):
                               rev, repoentity.path)
                 raise
             if not rev % commitevery:
-                repoentity.set_attributes(latest_known_revision=rev)
                 # give a change to threads waiting for a pool by freeing it then
                 # reacquiring it
                 session.commit()
                 session.set_pool()
-        if actualrev > latestrev:
-            repoentity.set_attributes(latest_known_revision=actualrev)
 
     def _file_content(self, path, rev):
         """extract a binary string with the content of the file at `path` for
