@@ -1,7 +1,7 @@
 """entity types used to represent a version control system (vcs) content
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -31,9 +31,6 @@ class Repository(EntityType):
     encoding = String(default='utf-8', maxsize=20, required=True,
                       description=_('encoding used for the repository (e.g.'
                                     ' for file path and check-in comments)'))
-    latest_known_revision = Int(default=0,
-                                description=_('latest revision known by the '
-                                              'source for this repository'))
 
 
 class Revision(EntityType):
