@@ -145,7 +145,7 @@ class VFPutUpdateAction(VFAction):
 class VFRmAction(VFAction):
     id = 'vcsrmaction'
     __select__ = VFAction.__select__ & \
-                 score_entity(lambda x: not x.revision_deleted())
+                 score_entity(lambda x: not x.deleted_in_branch())
 
     title = _('mark this file as deleted in the repository')
     category = 'moreactions'
