@@ -2,7 +2,7 @@
 some information about existing revisions.
 
 :organization: Logilab
-:copyright: 2007-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2007-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -50,7 +50,7 @@ class VCInlinedCreationFormView(editforms.InlineEntityCreationFormView):
         @cached
         def _entity(self):
             """creation view for an entity"""
-            vf = self.req.eid_rset(int(self.req.form['vfeid'])).get_entity(0, 0)
+            vf = self.req.entity_from_eid(int(self.req.form['vfeid']))
             self.orig_entity = vf.head
             # need a fully completed entity before doing the copy
             self.orig_entity.complete()
@@ -73,7 +73,7 @@ class VCInlinedCreationFormView(editforms.InlineEntityCreationFormView):
 
         def call(self, etype, peid, rtype, role='subject', **kwargs):
             """creation view for an entity"""
-            vf = self.req.eid_rset(int(self.req.form['vfeid'])).get_entity(0, 0)
+            vf = self.req.entity_from_eid(int(self.req.form['vfeid']))
             self.orig_entity = vf.head
             # need a fully completed entity before doing the copy
             self.orig_entity.complete()
@@ -140,13 +140,13 @@ class NewRevisionForm(forms.EntityFieldsForm):
 
     form_renderer_id = 'base'
     form_buttons = [fwdgs.SubmitButton()]
-    @property
-    def action(self):
-        return self.build_url('vcsnewrev')
 
     file = fields.FileField(eidparam=True)
     branch = fields.StringField(required=True, eidparam=True,
-                                widget=fwdgs.Select, choices=available_branches)
+                                widget=fwdgs.Select, choices=available_branches,
+                                # XXX in 3.6, uncomment this / remove formvalues
+                                #initial=lambda formentity.repository.default_branch()
+                                )
     msg = fields.StringField(label=_('commit message'), eidparam=True)
 
 
@@ -155,6 +155,9 @@ class VFUploadFormView(form.FormViewMixIn, EntityView):
     id = 'vfnewrevform'
     __select__ = implements('VersionedFile')
 
+    submitmsg = _('new revision has been checked-in')
+    action = 'vcsnewrev'
+
     def call(self, **_kwargs):
         # XXX explain why we would want self.rset.rowcount != 1
         for i in xrange(self.rset.rowcount):
@@ -170,11 +173,14 @@ class VFUploadFormView(form.FormViewMixIn, EntityView):
         self.w(u'<div class="iformTitle">')
         self.w(self.form_title(entity))
         self.w(u'</div>')
-        form = self.vreg.select_object('forms', 'vfnewrevform', self.req, entity=entity,
-                                       __redirectpath=entity.rest_path(),)
+        form = self.vreg['forms'].select(
+            'vfnewrevform', self.req, entity=entity,
+            submitmsg=self.req._(self.submitmsg), action=self.action,
+            __redirectpath=entity.rest_path(),)
         self.additional_form_fields(form, entity)
         # give default values so it won't try to get them from the entity
-        self.w(form.form_render(branch=entity.repository.default_branch(), file=u'', msg=u''))
+        self.w(form.render(formvalues=dict(branch=entity.repository.default_branch(),
+                                           file=u'', msg=u'')))
 
     def additional_form_fields(self, form, entity):
         pass
@@ -187,13 +193,17 @@ class VFUploadController(controller.Controller):
     def publish(self, rset=None):
         for eid in self.req.edited_eids():
             formparams = self.req.extract_entity_params(eid, minparams=2)
-            vf = self.req.eid_rset(eid).get_entity(0, 0)
+            vf = self.req.entity_from_eid(eid)
             vf.complete()
             self.upload_revision(vf, formparams)
         try:
-            goto = self.req.build_url(self.req.form['__redirectpath'])
+            kwargs = {'__message': self.req.form['__message']}
         except KeyError:
-            goto = vf.absolute_url()
+            kwargs = {}
+        try:
+            goto = self.req.build_url(self.req.form['__redirectpath'], **kwargs)
+        except KeyError:
+            goto = vf.absolute_url(**kwargs)
         raise Redirect(goto)
 
     def upload_revision(self, vf, formparams):
@@ -232,7 +242,7 @@ class VcsRmController(controller.Controller):
         req = self.req
         for eid in req.edited_eids():
             formparams = req.extract_entity_params(eid, minparams=2)
-            vf = self.req.eid_rset(eid).get_entity(0, 0)
+            vf = self.req.entity_from_eid(eid)
             vf.vcs_rm(msg=formparams['msg'])
         msg = req._('file was marked DELETED')
         raise Redirect(vf.absolute_url(__message=msg))
