@@ -134,7 +134,7 @@ class VFPrimaryView(primary.PrimaryView):
     def render_entity_attributes(self, entity):
         super(VFPrimaryView, self).render_entity_attributes(entity)
         self.w(u'<div class="content">')
-        if entity.revision_deleted():
+        if entity.deleted_in_branch():
             self.w(_('this file is currently deleted in the version control system'))
         else:
             head = entity.head
